syncer

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 3, 2025 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Overview

Package syncer provides the syncer implementation.

This package is responsible for syncing the BPF maps with the incoming data from the controller. It is also responsible for resolving DNS queries.

Code generated by MockGen. DO NOT EDIT. Source: resolver.go

Generated by this command:

mockgen -source=resolver.go -destination=resolver_mock.go -package=syncer

Package syncer is a generated GoMock package.

Index

Constants

const Subsystem = "go-syncer"

Variables

This section is empty.

Functions

This section is empty.

Types

type DNSResolver

type DNSResolver interface {
	LookupIPAddr(ctx context.Context, host string) ([]net.IPAddr, error)
}

type MockDNSResolver

type MockDNSResolver struct {
	// contains filtered or unexported fields
}

MockDNSResolver is a mock of DNSResolver interface.

func NewMockDNSResolver

func NewMockDNSResolver(ctrl *gomock.Controller) *MockDNSResolver

NewMockDNSResolver creates a new mock instance.

func (*MockDNSResolver) EXPECT

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockDNSResolver) LookupIPAddr

func (m *MockDNSResolver) LookupIPAddr(ctx context.Context, host string) ([]net.IPAddr, error)

LookupIPAddr mocks base method.

type MockDNSResolverMockRecorder

type MockDNSResolverMockRecorder struct {
	// contains filtered or unexported fields
}

MockDNSResolverMockRecorder is the mock recorder for MockDNSResolver.

func (*MockDNSResolverMockRecorder) LookupIPAddr

func (mr *MockDNSResolverMockRecorder) LookupIPAddr(ctx, host any) *gomock.Call

LookupIPAddr indicates an expected call of LookupIPAddr.

type ResolverService

type ResolverService struct {
	// contains filtered or unexported fields
}

func NewResolverService

func NewResolverService(reqChan chan *entities.PathRequest) *ResolverService

func (*ResolverService) ProcessConfig

func (rs *ResolverService) ProcessConfig(ctx context.Context) error

func (*ResolverService) ResolveIPv6Addresses

func (rs *ResolverService) ResolveIPv6Addresses(ctx context.Context, domainName string) ([]net.IPAddr, error)

func (*ResolverService) Start

func (rs *ResolverService) Start()

type Syncer

type Syncer struct {
	ErrCh chan error
	// contains filtered or unexported fields
}

func NewSyncer

func NewSyncer(bpf bpf.Bpf, adapterChannels *messaging.AdapterChannels, cm *maps.ClientMap) *Syncer

func (*Syncer) FetchAll

func (s *Syncer) FetchAll()

func (*Syncer) Start

func (s *Syncer) Start()

Jump to