types

package
v1.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 3, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package types provides type conversions and type definitions.

This package is used in combination with the api package to provide type conversions and type definitions.

Index

Constants

Variables

This section is empty.

Functions

This section is empty.

Types

type IntentType

type IntentType api.IntentType

func ParseIntentType

func ParseIntentType(s string) (IntentType, error)

func (IntentType) String

func (it IntentType) String() string

type IntentValueType

type IntentValueType api.ValueType

func ParseIntentValueType

func ParseIntentValueType(s string) (IntentValueType, error)

func (IntentValueType) String

func (ivt IntentValueType) String() string

Jump to