Documentation
¶
Overview ¶
Package client provides the client specific functions.
This package is responsible for handling the client side of the BPF implementation. It attaches the client eBPF programs to the interfaces on the host. It also creates the client side maps.
This package is also responsible to start the gRPC client and connect to the controller. It manages the different goroutines and channels.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ControllerClient ¶
type ControllerClient struct {
// contains filtered or unexported fields
}
func NewControllerClient ¶
func NewControllerClient(mainErrCh chan error, clientMap *maps.ClientMap) *ControllerClient
func (*ControllerClient) Start ¶
func (cc *ControllerClient) Start()
type EbpfClient ¶
type EbpfClient struct {
// contains filtered or unexported fields
}
func NewEbpfClient ¶
func (*EbpfClient) Start ¶
func (ec *EbpfClient) Start()
func (*EbpfClient) Stop ¶
func (ec *EbpfClient) Stop()
Click to show internal directories.
Click to hide internal directories.