Documentation
¶
Overview ¶
Package types provides type conversions and type definitions.
This package is used in combination with the api package to provide type conversions and type definitions.
Index ¶
Constants ¶
const ( IntentValueTypeUnspecified = IntentValueType(api.ValueType_VALUE_TYPE_UNSPECIFIED) IntentValueTypeMinValue = IntentValueType(api.ValueType_VALUE_TYPE_MIN_VALUE) IntentValueTypeMaxValue = IntentValueType(api.ValueType_VALUE_TYPE_MAX_VALUE) IntentValueTypeSFC = IntentValueType(api.ValueType_VALUE_TYPE_SFC) IntentValueTypeFlexAlgoNr = IntentValueType(api.ValueType_VALUE_TYPE_FLEX_ALGO_NR) )
const ( IntentTypeUnspecified = IntentType(api.IntentType_INTENT_TYPE_UNSPECIFIED) IntentTypeHighBandwidth = IntentType(api.IntentType_INTENT_TYPE_HIGH_BANDWIDTH) IntentTypeLowBandwidth = IntentType(api.IntentType_INTENT_TYPE_LOW_BANDWIDTH) IntentTypeLowLatency = IntentType(api.IntentType_INTENT_TYPE_LOW_LATENCY) IntentTypeLowPacketLoss = IntentType(api.IntentType_INTENT_TYPE_LOW_PACKET_LOSS) IntentTypeLowJitter = IntentType(api.IntentType_INTENT_TYPE_LOW_JITTER) IntentTypeFlexAlgo = IntentType(api.IntentType_INTENT_TYPE_FLEX_ALGO) IntentTypeSfc = IntentType(api.IntentType_INTENT_TYPE_SFC) IntentTypeLowUtilization = IntentType(api.IntentType_INTENT_TYPE_LOW_UTILIZATION) )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IntentType ¶
type IntentType api.IntentType
func ParseIntentType ¶
func ParseIntentType(s string) (IntentType, error)
func (IntentType) String ¶
func (it IntentType) String() string
type IntentValueType ¶
func ParseIntentValueType ¶
func ParseIntentValueType(s string) (IntentValueType, error)
func (IntentValueType) String ¶
func (ivt IntentValueType) String() string
Click to show internal directories.
Click to hide internal directories.